"use client";

import { useTranslations } from "next-intl";
import { useEffect, useState } from "react";

import CountDown from "@/components/common/count-down";
import { InputOTP, InputOTPGroup, InputOTPSeparator, InputOTPSlot } from "@/components/ui/input-otp";
import PhoneInput from "@/components/ui/phone-input";
import ShinyButton from "@/components/ui/shiny-button";
import { updatePhone, verifyPhone } from "@/servers/actions/userinfo-action";
import { useUserInfo } from "@/servers/data/use-userinfo";
import { toast } from "sonner";

function PrivacyTable() {
	const t = useTranslations("UserAccount");
	const { userInfo, refetch } = useUserInfo();

	const [phoneNumber, setPhoneNumber] = useState<string>(userInfo?.phone || "");
	const [isEditing, setIsEditing] = useState<boolean>(false);
	const [isVerifing, setIsVerifing] = useState<boolean>(false);
	const [timeLeft, setTimeLeft] = useState(180);
	const [isTimerRunning, setIsTimerRunning] = useState(true);
	const [otpValue, setOtpValue] = useState<string>("");


	useEffect(() => {
		setPhoneNumber(userInfo?.phone?.slice(3) || "");
	}, [userInfo]);

	const handleOtpChange = (value: string) => {
		setOtpValue(value);

	};

	const verifyOtp = async () => {
		try {
			if (otpValue.length < 4) return;

			const result = await verifyPhone(phoneNumber, otpValue);
			console.log("result: ", result);
			if (result?.status) {
				toast.success(t("OTP verified successfully"), {
					duration: 3000,
					icon: "🔑",
					style: {
						backgroundColor: "green",
						color: "white",
					},
				});
				setIsVerifing(false);
				setIsTimerRunning(false);
				await refetch();
			} else {
				toast.error(t("Something went wrong"));
			}
		} catch (error) {
			console.log("error: ", error);
			toast.error(t("Something went wrong"));
		}
	};


	const updatePhoneNumber = async () => {
		try {

			const result = await updatePhone(phoneNumber);
			console.log("result: ", result);
			if (result?.status) {
				toast.success(t("Verification code sent successfully, It is valid for 3 minutes"));
				setIsEditing(false);
				setIsVerifing(true);

			} else {
				toast.error(t("Something went wrong"));
			}

		} catch (error) {
			console.log("error: ", error);
			toast.error(t("Something went wrong"));
		}
	};

	return (
		<div className="">
			<p className="mb-6 mt-5 text-center text-lg font-semibold leading-5 text-custom-fourth md:mt-0 md:text-start md:text-base md:font-normal">
				{t("CompletePrivacyTable.Privacy")}
			</p>

			<div>
				<div>
					<div className="flex items-center justify-between border-b-[1px] border-dashed border-[#DEE2E6] py-6">
						<div className="flex-[33.3%]">
							<p className="mb-1 text-sm text-custom-fourth">
								{t("Phone Number")}
							</p>
							{isEditing ? (

								<div className="col-span-4 rounded-md border border-gray-300 bg-white h-11 mt-3 p-2">
									<PhoneInput
										value={phoneNumber}
										onChange={setPhoneNumber}
										labelclassName="text-right"
										className="h-12 -mt-2"
									/>
								</div>
							)
								: (
									<p className="text-sm text-custom-fifth">
										{`966${phoneNumber}`}
									</p>
								)}
							{isVerifing && (
								<div className="flex items-center gap-6">
									<div dir="ltr">
										<InputOTP maxLength={4} value={otpValue} onChange={handleOtpChange}>
											<InputOTPGroup>
												<InputOTPSlot index={0} className="border border-custom-secondary" />
												<InputOTPSlot index={1} className="border border-custom-secondary" />
											</InputOTPGroup>
											<InputOTPSeparator />
											<InputOTPGroup>
												<InputOTPSlot index={2} className="border border-custom-secondary" />
												<InputOTPSlot index={3} className="border border-custom-secondary" />
											</InputOTPGroup>
										</InputOTP>
									</div>
									<CountDown timeLeft={timeLeft} setTimeLeft={setTimeLeft} isTimerRunning={isTimerRunning} />
								</div>
							)}
						</div>

						<div className="flex flex-[33.3%] justify-end">
							<div className="flex flex-wrap justify-end gap-2">
								<ShinyButton
									className="bg-[#E9ECEF]"
									onClick={() => {
										if (isEditing) {
											updatePhoneNumber();
										} else if (isVerifing) {
											verifyOtp();
										} else {
											setIsEditing(true);
										}
									}}
								>
									<p className="text-sm text-[#6C757D]">
										{isEditing ? t("Save") : isVerifing ? t("Verify") : t("Change")}
									</p>
								</ShinyButton>
							</div>
						</div>
					</div>
				</div>
			</div>
		</div>
	);
}

export default PrivacyTable;
